Editor Test

# Test file for Editor EnterKeyHandling plugin

## blockNodeforEnter='BR'

para 1
line 2

para 2
line 2

## blockNodeforEnter='DIV'

para 1
line 2

para 2
line 2

## blockNodeforEnter='DIV' split test

this is a line of text. It IS intended to be split up by pressing enter.

## blockNodeforEnter='DIV' split test style clone

this is a line of text. It IS intended to be split up by pressing enter.

## blockNodeforEnter='DIV' split test font clone

this is a line of text. It IS intended to be split up by pressing enter.

## blockNodeforEnter='P'

para 1
line 2

para 2
line 2

## blockNodeforEnter='P' split test

this is a line of text. It IS intended to be split up by pressing enter.